#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-KDidrZrQL659pST8exoDHn
key:                  coinbase-pro-0.9.3.2-KDidrZrQL659pST8exoDHn
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  649e8269dfdffdfa1bd35783c37a46ef
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-KDidrZrQL659pST8exoDHn
depends:
    HsOpenSSL-0.11.7.10-E6Zp7QGcfDi7RFhtYd6KkS
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT
    aeson-casing-0.2.0.0-9ycUUTdjhdWEFQFcyE6KF3
    async-2.2.6-13RsU0DgnQr2Fu0srq1209 base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-2RFO5yAwnez2byeJv5SV6V exceptions-0.10.7
    http-api-data-0.6.1-1xw9sKY2pnsL9616EKbdpw
    http-client-0.7.19-3CnIhmcn0K76iPGUX0cQMN
    http-client-tls-0.3.6.4-5gkLBXAH8K17sWQOnZNh1
    http-streams-0.8.9.9-1wGywY9rLls2etSClvsAJQ
    http-types-0.12.4-KOR1gLg6ER2IlcqJ0qNtQq
    io-streams-1.5.2.2-52a6WRm7JQwBOijvu9lUyh
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-6Vir8NKcwTtGDZOkjzNXEQ
    servant-0.20.3.0-4N5aDL3IjARKTCNiquvhCG
    servant-client-0.20.3.0-KPL8OB00ElG97jIJpJUBCH
    servant-client-core-0.20.3.0-5YDZvhb2OjFEzSZYn1o428
    tasty-1.5.3-6dATjK2GfiuKOdbpItHINb
    tasty-hunit-0.10.2-KGbRGotZbhFnUjCpSchXP text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-FXrCafbaVapDDnZDep03Un
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits
    uuid-1.3.16.1-L1O8TurgJfVK0OVoZ8lrSO
    vector-0.13.2.0-1mI63yzxbUH28Wn11C5uSI
    websockets-0.12.7.3-B2b6b2xldknCmZPje7nyQj
    wuss-2.0.1.7-KdeIF9gApLaKz4Qku2aONe

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

